@@ -16,9 +16,9 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {imboxfilt} @var{J} = imboxfilt(@var{img})
-## @deftypefnx {imboxfilt} @var{J} = imboxfilt(@dots{_}, @var{fs})
-## @deftypefnx {imboxfilt} @var{J} = imboxfilt(@dots{}, @var{name}, @var{value}, @dots{} )
+## @deftypefn  {Function File} @var{J} = imboxfilt(@var{img})
+## @deftypefnx {Function File} @var{J} = imboxfilt(@dots{_}, @var{fs})
+## @deftypefnx {Function File} @var{J} = imboxfilt(@dots{}, @var{name}, @var{value}, @dots{} )
 ## Produces box filtering @var{J} of image @var{img}, is quicker than imfilter.
 ##
 ## Parameters:
